<?php
/**
 * Configuration functions for news_client.
 */

/**
 * Page callback for admin/config/news_client.
 */
function news_client_admin_page() {
  $build = array();
  
  $build['settings'] = drupal_get_form('news_client_admin_settings_form');
  $build['settings_test'] = drupal_get_form('news_client_admin_settings_test_form');
  
  return $build;
}

/**
 * General admin settings form.
 */
function news_client_admin_settings_form() {
  $sites_list = _news_client_fetch_sites_list();
  
  $sites_reference = '';
  
  if (!is_null($sites_list)) {
    $header = array(
      array('data' => t('Site Name')),
      array('data' => t('Site Tid')),
      array('data' => t('Domain')),
    );
  
    $rows = array();
  
    foreach ($sites_list as $id => $data) {
      $rows[] = array($data['name'], $id, $data['canonical_domain']);
    }
    
    $sites_reference_variables = array(
      'header' => $header,
      'rows' => $rows,
      'empty' => t('No site data.'),
      'caption' => t('Site Reference from news service.'),
    );
    
    $sites_reference = theme('table', $sites_reference_variables);
  }
  
  $form = array();
  
  $form['news_client_oauth2_server_url'] = array(
    '#type' => 'textfield',
    '#title' => t('OAuth2 Server URL'),
    '#description' => t('URL of the news service\'s OAuth2 server. (Add an ending slash.)'),
    '#default_value' => variable_get('news_client_oauth2_server_url', 'https://staff.it.osu.edu/'),
  );
  
  $form['news_client_service_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Service Path'),
    '#description' => t('Path of the news service endpoint. (Add an ending slash.)'),
    '#default_value' => variable_get('news_client_service_path', 'news_service/article/'),
  );
  
  $form['news_client_service_update_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Update Service Path'),
    '#description' => t('Path of the news service update endpoint. (Add an ending slash.)'),
    '#default_value' => variable_get('news_client_service_update_path', 'news_service/article_updates/'),
  );
  
  $form['news_client_sites_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Sites Service Path'),
    '#description' => t('Path of the news service sites endpoint. (Add an ending slash.)'),
    '#default_value' => variable_get('news_client_sites_path', 'news_service/sites/'),
  );
  
  $form['news_client_site_identifiers'] = array(
    '#type' => 'textfield',
    '#title' => t('Site Tid(s)'),
    '#description' => t('A comma delimited list of tids representing sites on the news service.') . '<br>' . $sites_reference,
    '#default_value' => variable_get('news_client_site_identifiers'),
  );
  
  return system_settings_form($form);
}

/**
 * Settings test form.
 */
function news_client_admin_settings_test_form($form, &$form_state) {
  $form = array();
  
  $form['actions'] = array(
    '#type' => 'actions',
  );
  
  $form['actions']['test_settings'] = array(
    '#type' => 'submit',
    '#value' => t('Test Configuration'),
  );
  
  return $form;
}

/**
 * Settings test form submit callback.
 */
function news_client_admin_settings_test_form_submit($form, &$form_state) {
  $sites = variable_get('news_client_site_identifiers');
  $article_page = _news_client_fetch_article_page(0, 10, $sites, '', 1);
  
  drupal_set_message(t('Test complete:<br><br>Results:<br> <pre>@article_page</pre>', array('@article_page' => print_r($article_page, TRUE))));
  
}
