<?php
/**
 * @file
 *  Batch functions for update processing.
 */

/**
 * Process a page of results from the news service.
 */
function news_client_batch_update_process_update($update, &$context) {
  if (!isset($context['sandbox']['progress'])) {
    $context['sandbox']['progress'] = 0;
  }
  
  // Process update.
  $nid = $update['nid'];
  $operation = $update['operation'];
  
  // Update progress info.
  $context['sandbox']['progress']++;
  $context['message'] = t('Now processing %operation on %nid', array('%operation' => $operation, '%nid' => $nid));
    
  switch ($operation) {
    case 'fetch':
      $article = _news_client_fetch_article($nid);
      
      $cached_article = NULL;
      
      if (!is_null($article) && !empty($article)) {
        $cached_article = _news_client_cached_article_populate($article);
      }
      
      if (!is_null($cached_article)) {
        $context['results'][] = t('%operation complete for %nid. (%title)', array('%operation' => $operation, '%nid' => $nid, '%title' => $cached_article->title));
      }
      else {
        $context['results'][] = t('%operation failed for %nid.', array('%operation' => $operation, '%nid' => $nid));
      }
      
      break;
    
    case 'remove':
      $query = new EntityFieldQuery();
      $query->entityCondition('entity_type', 'node');
      $query->entityCondition('bundle', 'news_client_cached_article');
      $query->fieldCondition('news_client_news_service_nid', 'value', $nid, '=');
      
      $result = $query->execute();
      
      if (isset($result['node'])) {
        $cached_article_nids = array_keys($result['node']);
        entity_delete_multiple('node', $cached_article_nids);
        $context['results'][] = t('%operation complete for %nid.', array('%operation' => $operation, '%nid' => $nid));
      }
      break;
  }
  
}

/**
 * Finish callback for news_client batch import.
 */
function news_client_batch_update_finished($success, $results, $operations) {
  if ($success) {
    // Here we do something meaningful with the results.
    $message = t('@count items successfully processed:', array('@count' => count($results)));
    $message .= theme('item_list', array('items' => $results));
    drupal_set_message($message);
    
    // Update last update time.
    variable_set('news_client_last_update', REQUEST_TIME);
  }
  else {
    // An error occurred.
    // $operations contains the operations that remained unprocessed.
    $error_operation = reset($operations);
    $message = t('An error occurred while processing %error_operation with arguments: @arguments', array('%error_operation' => $error_operation[0], '@arguments' => print_r($error_operation[1], TRUE)));
    drupal_set_message($message, 'error');
  }
}
