<?php

/**
 * @file
 * Implements Field module hooks for jqueryui formatters.
 */

/**
 * Implements hook_field_formatter_info().
 */
function ocio_field_bases_field_formatter_info() {
  return array(
    'ocio_field_bases_accordion' => array(
      'label' => t('Accordion'),
      'field types' => array('text', 'text_long', 'text_with_summary'),
    ),
  );
}

/**
 * Implements hook_field_formatter_view().
 */
function ocio_field_bases_field_formatter_view($entity_type, $entity, $field, $instance, $langcode, $items, $display) {

  $element = array();
  $settings = $display['settings'];
  $entity_id = (entity_id($entity_type, $entity));
  $field_id = $field['id'];
  $instance_id = $instance['id'];
  $unique_instance_id = $entity_id . '-' . $field_id . '-' . $instance_id;

  switch ($display['type']) {
    case 'ocio_field_bases_accordion':

      if (!empty($items)) {

        $element[] = array(
          '#theme' => 'ocio_field_bases_accordion',
          '#header' => $settings['header'],
          '#instance' => $instance,
          '#langcode' => $langcode,
          '#items' => $items,
          '#unique_instance_id' => $unique_instance_id,
        );
      }
      break;
    default:
      break;
  }

  return $element;
}


/**
 * Returns HTML for an dialog field formatter.
 *
 * @param array $variables
 *   An associative array containing:
 *   - header: header html tag to build the element,
 *   - instance: Associative array of instance field data,
 *   - langcode: field langcode,
 *   - items: Associative array containing the multiple
 *     values of an instance to be rendered,
 *   - unique_instance_id: unique id for instance,
 *
 * @ingroup themeable
 */
function theme_ocio_field_bases_accordion($vars) {
  $items = $vars['items'];
  $instance = $vars['instance'];

  $output = '<div class="ui-accordion"><div class="accordion-item"><div class="ui-accordion-header">'. $instance['label'] . '</div><div class="ui-accordion-content">';

  if (count($items) > 1) {
    $output .= '<div class="ui-accordion">';
    foreach ($items as $delta => $item) {
      $output .= '<div class="accordion-item"><div class="ui-accordion-header">' . $instance['label'] . ' ' . $delta . '</div><div class="ui-accordion-content">' . $items[$delta]['safe_value'] . '</div></div>';
    }
    $output .= '</div>';
  }
  else {
    $output .= $items[0]['safe_value'];
  }

  $output .= '</div></div></div>';

  return $output;
}
